@@ -22,9 +22,11 @@ class FlipperProvider(object):
     def auth(self, environment):
         LOG.info("Conecting with flipper...")
         credentials = self.get_credentials(environment= environment)
-        return MySQLdb.connect(host=credentials.endpoint, port=3306,
-                                     user=credentials.user, passwd=credentials.password,
-                                     db=credentials.project)
+        endpoint, database = credentials.endpoint.split('/')
+        host, port = endpoint.split(':')
+        return MySQLdb.connect(host=host, port=int(port),
+                               user=credentials.user, passwd=credentials.password,
+                               db=database)
     
 
     @classmethod
